Data documentation compiled by Great Expectations

### Overview

#### Dataset info

Number of variables | 7
Number of observations expect_table_row_count_to_be_between | 1313
Missing cells | 6.06%

#### Variable types

int | 3
float | 1
string | 3
unknown | 0

#### Expectation types

- expect_column_proportion_of_unique_values_to_be_between 7
- expect_column_unique_value_count_to_be_between 7
- expect_column_values_to_be_in_set 7
- expect_column_values_to_be_in_type_list 7
- expect_column_values_to_not_be_null 7
- expect_column_distinct_values_to_be_in_set 4
- expect_column_values_to_not_match_regex 3
- expect_column_values_to_be_unique 1
- expect_column_max_to_be_between 1
- expect_table_row_count_to_be_between 1
- expect_column_quantile_values_to_be_between 1
- expect_column_kl_divergence_to_be_less_than 1
- expect_column_median_to_be_between 1
- expect_table_columns_to_match_ordered_list 1
- expect_column_mean_to_be_between 1
- expect_column_min_to_be_between 1

### Unnamed: 0 expect_column_to_exist

##### Type: int expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Properties

Distinct (n) expect_column_unique_value_count_to_be_between | 1313
Distinct (%) expect_column_proportion_of_unique_values_to_be_between | 100.0%
Missing (n) expect_column_values_to_not_be_null | 0
Missing (%) expect_column_values_to_not_be_null | 0.0%

#### Example Values expect_column_values_to_be_in_set

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20

### Name expect_column_to_exist

##### Type: string expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Properties

Distinct (n) expect_column_unique_value_count_to_be_between | 1310
Distinct (%) expect_column_proportion_of_unique_values_to_be_between | 99.8%
Missing (n) expect_column_values_to_not_be_null | 0
Missing (%) expect_column_values_to_not_be_null | 0.0%

#### Example Values expect_column_values_to_be_in_set

Carlsson, Mr Frans Olof Connolly, Miss Kate Kelly, Mr James Carter, Rev Ernest Courtenay Compton, Miss Sara Rebecca Drew, Mr James Vivian Duran y More, Miss Asuncion Eustis, Miss Elizabeth Mussey Hee, Mr Ling Hegarty, Miss Nora Herman, Miss Alice Kenyon, Mr Frederick R Louch, Mrs Charles Alexander (Alice Adelaide) Markim, Mr Johann Murphy, Miss Katherine Myles, Mr Thomas Francis Panula, Mrs John Peacock, Miss Treasteall Tannous, Mr Thomas Veale, Mr James

### PClass expect_column_to_exist

##### Type: string expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Properties

Distinct (n) expect_column_unique_value_count_to_be_between | 4
Distinct (%) expect_column_proportion_of_unique_values_to_be_between | 0.3%
Missing (n) expect_column_values_to_not_be_null | 0
Missing (%) expect_column_values_to_not_be_null | 0.0%

#### Example Values expect_column_values_to_be_in_set

3rd 1st 2nd *

#### Value Counts expect_column_distinct_values_to_be_in_set

### Age expect_column_to_exist

##### Type: float expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Properties

Distinct (n) expect_column_unique_value_count_to_be_between | 75
Distinct (%) expect_column_proportion_of_unique_values_to_be_between | 9.9%
Missing (n) expect_column_values_to_not_be_null | 557
Missing (%) expect_column_values_to_not_be_null | 42.4%

#### Quantiles

0.05 expect_column_quantile_values_to_be_between | 6.0
Q1 expect_column_quantile_values_to_be_between | 21.0
Median expect_column_quantile_values_to_be_between expect_column_median_to_be_between | 28.0
Q3 expect_column_quantile_values_to_be_between | 39.0
0.95 expect_column_quantile_values_to_be_between | 57.0

#### Statistics

Mean expect_column_mean_to_be_between | 30.40
Minimum expect_column_min_to_be_between | 0.17
Maximum expect_column_max_to_be_between | 71.00

#### Histogram expect_column_kl_divergence_to_be_less_than

#### Example Values expect_column_values_to_be_in_set

22.0 21.0 30.0 18.0 36.0 24.0 26.0 27.0 28.0 19.0 20.0 23.0 25.0 32.0 45.0 29.0 31.0 33.0 35.0 39.0

### Sex expect_column_to_exist

##### Type: string expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Properties

Distinct (n) expect_column_unique_value_count_to_be_between | 2
Distinct (%) expect_column_proportion_of_unique_values_to_be_between | 0.2%
Missing (n) expect_column_values_to_not_be_null | 0
Missing (%) expect_column_values_to_not_be_null | 0.0%

#### Example Values expect_column_values_to_be_in_set

male female

#### Value Counts expect_column_distinct_values_to_be_in_set

### Survived expect_column_to_exist

##### Type: int expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Properties

Distinct (n) expect_column_unique_value_count_to_be_between | 2
Distinct (%) expect_column_proportion_of_unique_values_to_be_between | 0.2%
Missing (n) expect_column_values_to_not_be_null | 0
Missing (%) expect_column_values_to_not_be_null | 0.0%

#### Example Values expect_column_values_to_be_in_set

0 1

#### Value Counts expect_column_distinct_values_to_be_in_set

### SexCode expect_column_to_exist

##### Type: int expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Properties

Distinct (n) expect_column_unique_value_count_to_be_between | 2
Distinct (%) expect_column_proportion_of_unique_values_to_be_between | 0.2%
Missing (n) expect_column_values_to_not_be_null | 0
Missing (%) expect_column_values_to_not_be_null | 0.0%

#### Example Values expect_column_values_to_be_in_set

0 1

#### Value Counts expect_column_distinct_values_to_be_in_set

Documentation autogenerated using Great Expectations.

This is a beta feature! Expect changes in API, behavior, and design.

Documentation autogenerated using Great Expectations.

This is a beta feature! Expect changes in API, behavior, and design.